==> gnome-software-3.15.90.tar.xz: gnome-software-3.15.90/src/gs-shell-overview.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GS_SHELL_OVERVIEW_H
#define __GS_SHELL_OVERVIEW_H

#include <glib-object.h>
#include <gtk/gtk.h>

#include "gs-app.h"
#include "gs-page.h"
#include "gs-shell.h"
#include "gs-plugin-loader.h"

G_BEGIN_DECLS

#define GS_TYPE_SHELL_OVERVIEW		(gs_shell_overview_get_type ())
#define GS_SHELL_OVERVIEW(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GS_TYPE_SHELL_OVERVIEW, GsShellOverview))
#define GS_SHELL_OVERVIEW_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), GS_TYPE_SHELL_OVERVIEW, GsShellOverviewClass))
#define GS_IS_SHELL_OVERVIEW(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), GS_TYPE_SHELL_OVERVIEW))
#define GS_IS_SHELL_OVERVIEW_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GS_TYPE_SHELL_OVERVIEW))
#define GS_SHELL_OVERVIEW_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GS_TYPE_SHELL_OVERVIEW, GsShellOverviewClass))

typedef struct GsShellOverviewPrivate GsShellOverviewPrivate;

typedef struct
{
	 GsPage			 parent;
	 GsShellOverviewPrivate	*priv;
} GsShellOverview;

typedef struct
{
	GsPageClass		 parent_class;

	void	(*refreshed)	(GsShellOverview *shell);
} GsShellOverviewClass;

GType		 gs_shell_overview_get_type	(void);

GsShellOverview	*gs_shell_overview_new		(void);
void		 gs_shell_overview_invalidate	(GsShellOverview	*shell_overview);
void		 gs_shell_overview_switch_to	(GsShellOverview	*shell_overview,
						 gboolean		scroll_up);
void		 gs_shell_overview_reload	(GsShellOverview	*shell_overview);
void		 gs_shell_overview_setup	(GsShellOverview	*shell_overview,
						 GsShell		*shell,
						 GsPluginLoader		*plugin_loader,
						 GtkBuilder		*builder,
						 GCancellable		*cancellable);
void		 gs_shell_overview_set_category	(GsShellOverview	*shell_overview,
						 const gchar		*category);

G_END_DECLS

#endif /* __GS_SHELL_OVERVIEW_H */

/* vim: set noexpandtab: */

==> gnome-software_3.20.5.orig.tar.xz: gnome-software-3.20.5/src/gs-shell-overview.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GS_SHELL_OVERVIEW_H
#define __GS_SHELL_OVERVIEW_H

#include <glib-object.h>
#include <gtk/gtk.h>

#include "gs-app.h"
#include "gs-page.h"
#include "gs-shell.h"
#include "gs-plugin-loader.h"

G_BEGIN_DECLS

#define GS_TYPE_SHELL_OVERVIEW (gs_shell_overview_get_type ())

G_DECLARE_DERIVABLE_TYPE (GsShellOverview, gs_shell_overview, GS, SHELL_OVERVIEW, GsPage)

struct _GsShellOverviewClass
{
	GsPageClass		 parent_class;

	void	(*refreshed)	(GsShellOverview *self);
};

GsShellOverview	*gs_shell_overview_new		(void);
void		 gs_shell_overview_invalidate	(GsShellOverview	*self);
void		 gs_shell_overview_reload	(GsShellOverview	*self);
void		 gs_shell_overview_setup	(GsShellOverview	*self,
						 GsShell		*shell,
						 GsPluginLoader		*plugin_loader,
						 GtkBuilder		*builder,
						 GCancellable		*cancellable);
void		 gs_shell_overview_set_category	(GsShellOverview	*self,
						 const gchar		*category);

G_END_DECLS

#endif /* __GS_SHELL_OVERVIEW_H */

/* vim: set noexpandtab: */
